## Summary

<!-- Brief description of what this PR does -->

## Changes

<!-- List of changes -->

-

## Type

<!-- Check one -->

- [ ] feat: New feature
- [ ] fix: Bug fix
- [ ] docs: Documentation
- [ ] test: Tests
- [ ] refactor: Code restructuring
- [ ] chore: Maintenance

## Checklist

- [ ] Tests added/updated
- [ ] All tests pass (`uv run pytest -v`)
- [ ] Linter passes (`uv run ruff check .`)
- [ ] Formatter passes (`uv run ruff format --check .`)
- [ ] Documentation updated (if applicable)
- [ ] Changelog updated (if user-facing change)
